==> istio-model-v1beta1-6.8.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluent<A extends LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluent<A>> extends BaseFluent<A>{
  public LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluent() {
  }
  public LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluent(LoadBalancerSettingsConsistentHashLBHttpQueryParameterName instance) {
    instance = (instance != null ? instance : new LoadBalancerSettingsConsistentHashLBHttpQueryParameterName());

    if (instance != null) {
      this.withHttpQueryParameterName(instance.getHttpQueryParameterName());
      this.withHttpQueryParameterName(instance.getHttpQueryParameterName());
    }
  }
  private String httpQueryParameterName;
  public String getHttpQueryParameterName() {
    return this.httpQueryParameterName;
  }
  public A withHttpQueryParameterName(String httpQueryParameterName) {
    this.httpQueryParameterName=httpQueryParameterName; return (A) this;
  }
  public boolean hasHttpQueryParameterName() {
    return this.httpQueryParameterName != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluent that = (LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluent) o;
    if (!java.util.Objects.equals(httpQueryParameterName, that.httpQueryParameterName)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(httpQueryParameterName,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (httpQueryParameterName != null) { sb.append("httpQueryParameterName:"); sb.append(httpQueryParameterName); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1beta1-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluent<A extends LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluent<A>> extends BaseFluent<A>{
  public LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluent() {
  }
  
  public LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluent(LoadBalancerSettingsConsistentHashLBHttpQueryParameterName instance) {
    this.copyInstance(instance);
  }
  private String httpQueryParameterName;
  
  protected void copyInstance(LoadBalancerSettingsConsistentHashLBHttpQueryParameterName instance) {
    instance = (instance != null ? instance : new LoadBalancerSettingsConsistentHashLBHttpQueryParameterName());
  
    if (instance != null) {
        this.withHttpQueryParameterName(instance.getHttpQueryParameterName());
        this.withHttpQueryParameterName(instance.getHttpQueryParameterName());
      }
  }
  
  public String getHttpQueryParameterName() {
    return this.httpQueryParameterName;
  }
  
  public A withHttpQueryParameterName(String httpQueryParameterName) {
    this.httpQueryParameterName=httpQueryParameterName; return (A) this;
  }
  
  public boolean hasHttpQueryParameterName() {
    return this.httpQueryParameterName != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluent that = (LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluent) o;
    if (!java.util.Objects.equals(httpQueryParameterName, that.httpQueryParameterName)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(httpQueryParameterName,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (httpQueryParameterName != null) { sb.append("httpQueryParameterName:"); sb.append(httpQueryParameterName); }
    sb.append("}");
    return sb.toString();
  }
  

}
